Stations are specified as one station per line in the file with the following fields:

- `station_id`: a unique identifier for the station
- `lat`: the latitude of the station location
- `lon`: the longitude of the station location
- `charger_count`: how many chargers of type `charger_id` are at this station
- `charger_id`: the corresponding charger id
- `on_shift_access`: is this station available to on shift human drivers?  
